% Created by John Hedengren

clear all
close all

global u T invT n red_n Tx_constant

% Number of internal nodes
n = 20;

% Steady State Initial Conditions for the borders
u(1) = 25 + 273.15;
u(2) = 25 + 273.15;

% Steady State Initial Conditions for the States
for i = 2:n+1,
   T0(i) = 25 + 273.15;
end

% Change temperature on the left side
u(1) = 100 + 273.15;

% Initial conditions
x0(1:n,1) = T0(2:n+1)';

% Final Time (sec)
tf = 600;
%tspan = [0 5 10 20 50 300];
%tspan = linspace(0,tf,10);
tspan = [0 tf];

[t,x] = ode15s('heat1d',tspan,x0);

[m,n] = size(x);

% Parse out the state values
Tf(1) = u(1);
Tf(2:n+1) = x(m,:);
Tf(n+2) = u(2);

% Width
width = 1;  % m
% Determine equal spacing between nodes
dx = width / (n+1);

dist(1) = 0;
for i = 2:n+2,
   dist(i) = dist(i-1) + dx;
end

% Plot the results
figure(1);
plot(dist,Tf);
xlabel('Distance (m)')
ylabel('Temperature (K)')
axis([0 1  290 380]);
hold on;



if (1),
% ========================= POD ========================================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Read in data --------------------------------------------------------------------------
load 'T_matrix_POD' T invT

% POD
red_n=2;

%Set up the step change
% same as last one

%Initial transformed states 
Tx_initial = T(1:red_n,:) * x0;
Tx_constant = T(red_n+1:n,:) * x0;

%Select time span
tspan = [0 tf];

%Integrate open loop simulated "actual" process
[t,Tx] = ode15s('heat1d_ROM',tspan,Tx_initial);

% Find out how many records (time steps) where stored (m_rows)
[m_rows,n_columns] = size(Tx);

%Store the reduced order model temperatures
big_Tx_const = Tx_constant';
for i = 2:m_rows
   big_Tx_const = [big_Tx_const;Tx_constant'];
end

Tx = [Tx big_Tx_const];

T_ROM = Tx * invT';

% Tack on left and right boundary conditions
T_ROM = [ones(m_rows,1)*u(1) T_ROM ones(m_rows,1)*u(2)];

% Take the last time shot for comparison
T_f_ROM = T_ROM(m_rows,:);

% Plot the results
figure(1);
plot(dist,T_f_ROM);
xlabel('Distance (m)')
ylabel('Temperature (K)')
axis([0 1  290 380]);
hold on;

end